@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Shape_detection/include/CGAL/Polygon_mesh_processing/region_growing.h $
-// $Id: include/CGAL/Polygon_mesh_processing/region_growing.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Shape_detection/include/CGAL/Polygon_mesh_processing/region_growing.h $
+// $Id: include/CGAL/Polygon_mesh_processing/region_growing.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -126,7 +126,7 @@ private:
       \cgalParamExtra{this parameter and `cosine_of_maximum_angle` are exclusive}
     \cgalParamNEnd
     \cgalParamNBegin{postprocess_regions}
-      \cgalParamDescription{Apply a post-processing step to the output of the region growing algorithm.}
+      \cgalParamDescription{Apply a postprocessing step to the output of the region growing algorithm.}
       \cgalParamType{`bool`}
       \cgalParamDefault{false}
     \cgalParamNEnd
@@ -212,7 +212,7 @@ region_growing_of_planes_on_faces(const PolygonMesh& mesh,
 
   if (choose_parameter(get_parameter(np, internal_np::postprocess_regions), false))
   {
-    // first try for a post-processing: look at regions made of one face and check if a
+    // first try for a postprocessing: look at regions made of one face and check if a
     // larger region contains its 3 vertices and if so assigned it to it.
     typedef typename boost::property_traits<RegionMap>::value_type Id;
     for (std::size_t i=0; i<tmp.size(); ++i)
