@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Vertex_conflict_C2.h $
-// $Id: include/CGAL/Segment_Delaunay_graph_2/Vertex_conflict_C2.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Vertex_conflict_C2.h $
+// $Id: include/CGAL/Segment_Delaunay_graph_2/Vertex_conflict_C2.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -443,10 +443,6 @@ private:
 
 
 public:
-  typedef Site_2      argument_type;
-  typedef Sign        result_type;
-
-
   Sign operator()(const Site_2& p, const Site_2& q,
                   const Site_2& r, const Site_2& t) const
   {
